# Emergency Reporting

This library is intended to provide an easy interface to the [Emergeny Reporting API](https://developer.emergencyreporting.com/).

This us currently in early active development.